@@ -12,10 +12,10 @@ from whatstk.whatsapp.parser import df_from_txt_whatsapp
 
 name = "whatstk"
 
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 
 __all__ = [
-    'WhatsAppChat',
-    'df_from_txt_whatsapp',
-    'FigureBuilder',
+    "WhatsAppChat",
+    "df_from_txt_whatsapp",
+    "FigureBuilder",
 ]
