@@ -1,11 +1,16 @@
 """Boxplot figures."""
 
+from typing import Dict, Optional
 
 import plotly.graph_objs as go
+import pandas as pd
+
 from whatstk.utils.utils import COLNAMES_DF
 
 
-def fig_boxplot_msglen(df, username_to_color=None, title="", xlabel=None):
+def fig_boxplot_msglen(
+    df: pd.DataFrame, username_to_color: Dict[str, str] = None, title: str = "", xlabel: Optional[str] = None
+) -> go.Figure:
     """Visualize boxplot.
 
     Args:
@@ -22,8 +27,11 @@ def fig_boxplot_msglen(df, username_to_color=None, title="", xlabel=None):
     # Get message lengths
     df[COLNAMES_DF.MESSAGE_LENGTH] = df[COLNAMES_DF.MESSAGE].apply(lambda x: len(x))
     # Sort users by median
-    user_stats = df.groupby(COLNAMES_DF.USERNAME)\
-        .aggregate({COLNAMES_DF.MESSAGE_LENGTH: 'median'})[COLNAMES_DF.MESSAGE_LENGTH].sort_values(ascending=False)
+    user_stats = (
+        df.groupby(COLNAMES_DF.USERNAME)
+        .aggregate({COLNAMES_DF.MESSAGE_LENGTH: "median"})[COLNAMES_DF.MESSAGE_LENGTH]
+        .sort_values(ascending=False)
+    )
 
     # Create a list of traces
     data = []
@@ -34,15 +42,12 @@ def fig_boxplot_msglen(df, username_to_color=None, title="", xlabel=None):
             y=x.values,
             showlegend=True,
             name=username,
-            boxpoints='outliers',
-            marker_color=username_to_color[username] if username_to_color else None
+            boxpoints="outliers",
+            marker_color=username_to_color[username] if username_to_color else None,
         )
         data.append(trace)
 
-    layout = dict(
-        title=title,
-        xaxis=dict(title=xlabel)
-    )
+    layout = dict(title=title, xaxis=dict(title=xlabel))
 
     fig = go.Figure(data=data, layout=layout)
 
