@@ -1,5 +1,11 @@
 """Utils."""
 
+from typing import TYPE_CHECKING
+import pandas as pd
+
+if TYPE_CHECKING:  # pragma: no cover
+    from whatstk._chat import BaseChat  # pragma: no cover
+
 
 class ColnamesDf:
     """Access class constants using variable ``whatstk.utils.utils.COLNAMES_DF``.
@@ -14,23 +20,24 @@ class ColnamesDf:
                 'date'
 
     """
-    DATE = 'date'
+
+    DATE = "date"
     """Date column"""
 
-    USERNAME = 'username'
+    USERNAME = "username"
     """Username column"""
 
-    MESSAGE = 'message'
+    MESSAGE = "message"
     """Message column"""
 
-    MESSAGE_LENGTH = 'message_length'
+    MESSAGE_LENGTH = "message_length"
     """Message length column"""
 
 
 COLNAMES_DF = ColnamesDf()
 
 
-def _get_df(df, chat):
+def _get_df(df: pd.DataFrame, chat: "BaseChat") -> pd.DataFrame:
     if (df is None) & (chat is None):
         raise ValueError("Please provide a chat, using either argument `df` or `chat`.")
     if (df is None) and (chat is not None):
@@ -38,7 +45,7 @@ def _get_df(df, chat):
     return df
 
 
-def _map_hformat_filename(filename):
+def _map_hformat_filename(filename: str) -> str:
     """Map hformat to valid filename (Linux, MacOS, Win).
 
     Args:
@@ -47,10 +54,5 @@ def _map_hformat_filename(filename):
     Returns:
         str: Mapped header format.
     """
-    filename = (
-        filename
-        .replace(' ', '_')
-        .replace('/', '--')
-        .replace(':', ';')
-    )
+    filename = filename.replace(" ", "_").replace("/", "--").replace(":", ";")
     return filename
